@@ -2,6 +2,7 @@ import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
 from statsmodels.tsa.stattools import grangercausalitytests
+import statsmodels.tsa.stattools as sts
 
 def fis_variable_frecuency(df_cat):
     """
@@ -204,6 +205,7 @@ def fis_TS_dickey_fuller_statistics(X_train):
     Habría que transformar los datos porque no se puede confirmar estacionariedad.
     """
     print('Augmented Dickey-Fuller Test:')
+    print('=============================')
     for column in X_train.columns:
         result = sts.adfuller(X_train[column].values)
         print("Temporal Serie for: ",column)
